EmissionRPC
===========

.. image:: https://badge.fury.io/py/emissionrpc.svg
    :target: https://badge.fury.io/py/emissionrpc

EmissionRPC, another wrapper JSON-RPC to Transmission


Usage
-----

Still in development

